# Changelog

All notable changes to this project will be documented in this file.

## Unreleased

// Add new changes below this line.

## v0.1.4 (2022-12-11)

- Added a friendly error message to the list collections method.
- Added additional automated tests.

## v0.1.3 (2022-12-04)

- Updated README on PyPI to show Python versions.

